pub trait ToNetwork<N: IpNet> {
// Required method
fn to_network(&self) -> N;
}Expand description
Anything that can be converted to IpNet.
Due to limitation of Rust’s type system, this trait is only implemented for some concrete types.
pub trait ToNetwork<N: IpNet> {
// Required method
fn to_network(&self) -> N;
}Anything that can be converted to IpNet.
Due to limitation of Rust’s type system, this trait is only implemented for some concrete types.